aboutsummaryrefslogtreecommitdiff
path: root/src/crepe/api
diff options
context:
space:
mode:
authorheavydemon21 <nielsstunnebrink1@gmail.com>2024-11-28 12:53:15 +0100
committerheavydemon21 <nielsstunnebrink1@gmail.com>2024-11-28 12:53:15 +0100
commit9d9c4fc4565f0ef0fc81c8baeef804389f07afc2 (patch)
treef8bfb75a2b99f40de8d8cfb68136bd0b8ee68a39 /src/crepe/api
parent1cdaa2aaeb1b6bc71876b462fcc464800ec75732 (diff)
implemented loek feedback
Diffstat (limited to 'src/crepe/api')
-rw-r--r--src/crepe/api/Animator.cpp12
-rw-r--r--src/crepe/api/Camera.cpp4
-rw-r--r--src/crepe/api/Camera.h4
-rw-r--r--src/crepe/api/Color.cpp2
-rw-r--r--src/crepe/api/Config.h7
-rw-r--r--src/crepe/api/Sprite.cpp8
-rw-r--r--src/crepe/api/Sprite.h14
7 files changed, 27 insertions, 24 deletions
diff --git a/src/crepe/api/Animator.cpp b/src/crepe/api/Animator.cpp
index 2b21c6c..0fdab0e 100644
--- a/src/crepe/api/Animator.cpp
+++ b/src/crepe/api/Animator.cpp
@@ -14,14 +14,14 @@ Animator::Animator(game_object_id_t id, Sprite & ss, int row, int col, int col_a
col(col) {
dbg_trace();
- this->spritesheet.sprite_rect.h /= col;
- this->spritesheet.sprite_rect.w /= row;
- this->spritesheet.sprite_rect.x = 0;
- this->spritesheet.sprite_rect.y = col_animator * this->spritesheet.sprite_rect.h;
+ this->spritesheet.mask.h /= col;
+ this->spritesheet.mask.w /= row;
+ this->spritesheet.mask.x = 0;
+ this->spritesheet.mask.y = col_animator * this->spritesheet.mask.h;
this->active = false;
// need to do this for to get the aspect ratio for a single clipping in the spritesheet
- this->spritesheet.aspect_ratio = static_cast<double>(this->spritesheet.sprite_rect.w)
- / this->spritesheet.sprite_rect.h;
+ this->spritesheet.aspect_ratio = static_cast<double>(this->spritesheet.mask.w)
+ / this->spritesheet.mask.h;
}
Animator::~Animator() { dbg_trace(); }
diff --git a/src/crepe/api/Camera.cpp b/src/crepe/api/Camera.cpp
index 0831f45..39d8ab0 100644
--- a/src/crepe/api/Camera.cpp
+++ b/src/crepe/api/Camera.cpp
@@ -8,12 +8,12 @@
using namespace crepe;
Camera::Camera(game_object_id_t id, const Color & bg_color, const ivec2 & screen,
- const ivec2 & viewport, const double & zoom, const vec2 & offset)
+ const vec2 & viewport_size, const double & zoom, const vec2 & offset)
: Component(id),
bg_color(bg_color),
offset(offset),
screen(screen),
- viewport(viewport),
+ viewport_size(viewport_size),
zoom(zoom) {
dbg_trace();
}
diff --git a/src/crepe/api/Camera.h b/src/crepe/api/Camera.h
index 3682222..2d8fa48 100644
--- a/src/crepe/api/Camera.h
+++ b/src/crepe/api/Camera.h
@@ -22,7 +22,7 @@ public:
* \param bg_color Background color for the camera view.
*/
Camera(game_object_id_t id, const Color & bg_color, const ivec2 & screen,
- const ivec2 & viewport, const double & zoom, const vec2 & offset = {0, 0});
+ const vec2 & viewport_size, const double & zoom, const vec2 & offset = {0, 0});
~Camera(); // dbg_trace only
public:
@@ -36,7 +36,7 @@ public:
const ivec2 screen;
//! viewport is the area of the world visible through the camera (in world units)
- const ivec2 viewport;
+ const vec2 viewport_size;
//! Zoom level of the camera view.
const double zoom;
diff --git a/src/crepe/api/Color.cpp b/src/crepe/api/Color.cpp
index dc7c15f..29bd77a 100644
--- a/src/crepe/api/Color.cpp
+++ b/src/crepe/api/Color.cpp
@@ -2,7 +2,7 @@
using namespace crepe;
-const Color Color::WHITE{0xff, 0xff, 0xff, 0xff};
+const Color Color::WHITE{0xff, 0xff, 0xff};
const Color Color::RED{0xff, 0x00, 0x00};
const Color Color::GREEN{0x00, 0xff, 0x00};
const Color Color::BLUE{0x00, 0x00, 0xff};
diff --git a/src/crepe/api/Config.h b/src/crepe/api/Config.h
index d73e488..225e9b9 100644
--- a/src/crepe/api/Config.h
+++ b/src/crepe/api/Config.h
@@ -2,6 +2,7 @@
#include "../util/Log.h"
#include "types.h"
+#include <string>
namespace crepe {
@@ -66,8 +67,10 @@ public:
//! default window settings
struct {
//TODO make this constexpr because this will never change
- ivec2 def_size = {1080, 720};
- } win_set;
+ ivec2 default_size = {1080, 720};
+ std::string window_title = "Jetpack joyride clone";
+
+ } window_settings;
//! Asset loading options
struct {
diff --git a/src/crepe/api/Sprite.cpp b/src/crepe/api/Sprite.cpp
index 65c6cc3..8647794 100644
--- a/src/crepe/api/Sprite.cpp
+++ b/src/crepe/api/Sprite.cpp
@@ -11,7 +11,7 @@ using namespace std;
using namespace crepe;
Sprite::Sprite(game_object_id_t id, Texture & image, const Color & color,
- const FlipSettings & flip, uint8_t sort_layer, uint8_t order_layer, int height)
+ const FlipSettings & flip, int sort_layer, int order_layer, int height)
: Component(id),
color(color),
flip(flip),
@@ -22,9 +22,9 @@ Sprite::Sprite(game_object_id_t id, Texture & image, const Color & color,
dbg_trace();
- this->sprite_rect.w = sprite_image.get_width();
- this->sprite_rect.h = sprite_image.get_height();
- this->aspect_ratio = static_cast<double>(this->sprite_rect.w) / this->sprite_rect.h;
+ this->mask.w = sprite_image.get_width();
+ this->mask.h = sprite_image.get_height();
+ this->aspect_ratio = static_cast<double>(this->mask.w) / this->mask.h;
}
Sprite::~Sprite() { dbg_trace(); }
diff --git a/src/crepe/api/Sprite.h b/src/crepe/api/Sprite.h
index e40ce24..a0e90a0 100644
--- a/src/crepe/api/Sprite.h
+++ b/src/crepe/api/Sprite.h
@@ -41,7 +41,7 @@ public:
* \param height the height of the image in game units
*/
Sprite(game_object_id_t id, Texture & image, const Color & color,
- const FlipSettings & flip, uint8_t sort_layer, uint8_t order_layer, int height);
+ const FlipSettings & flip, int sort_layer, int order_layer, int height);
/**
* \brief Destroys the Sprite instance.
@@ -58,9 +58,9 @@ public:
FlipSettings flip;
//! Layer sorting level of the sprite
- const uint8_t sorting_in_layer;
+ const int sorting_in_layer;
//! Order within the sorting layer
- const uint8_t order_in_layer;
+ const int order_in_layer;
//! height in world units
const int height;
@@ -74,13 +74,13 @@ public:
double aspect_ratio;
private:
//! Reads the sprite_rect of sprite
friend class SDLContext;
//! Reads the all the variables plus the sprite_rect
friend class Animator;
//! Reads the all the variables plus the sprite_rect
friend class AnimatorSystem;
struct Rect {
@@ -91,7 +91,7 @@ private:
};
//! Render area of the sprite this will also be adjusted by the AnimatorSystem if an Animator
// object is present in GameObject. this is in sprite pixels
- Rect sprite_rect;
+ Rect mask;
};
} // namespace crepe
@@ -74,13 +74,13 @@ public:
double aspect_ratio;
private:
- //! Reads the sprite_rect of sprite
+ //! Reads the mask of sprite
friend class SDLContext;
@@ -74,13 +74,13 @@ public:
friend class SDLContext;
- //! Reads the all the variables plus the sprite_rect
+ //! Reads the all the variables plus the mask
friend class Animator;
@@ -74,13 +74,13 @@ public:
friend class Animator;
- //! Reads the all the variables plus the sprite_rect
+ //! Reads the all the variables plus the mask
friend class AnimatorSystem;
struct Rect {